==> haskell-patience-0.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: patience
version: 0.1.1
id: patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
key: patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
license: BSD3
maintainer: Keegan McAllister <mcallister.keegan@gmail.com>
synopsis: Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.
    .
    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.
    .
    New in version 0.1.1: relaxed @containers@ dependency, so it should build on
    GHC 6.10.
category: Algorithms, Text
author: Keegan McAllister <mcallister.keegan@gmail.com>
exposed: True
exposed-modules:
    Data.Algorithm.Patience
abi: 4c45d7eb2e8a67f4f9eaa765fddfb94b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/patience-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/patience-0.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/patience-0.1.1
hs-libraries: HSpatience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
depends:
    base-4.9.0.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html: /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-patience-0.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: patience
version: 0.1.1
id: patience-0.1.1-2guNJXEyIQ0FLSljxNeNTz
key: patience-0.1.1-2guNJXEyIQ0FLSljxNeNTz
license: BSD3
maintainer: Keegan McAllister <mcallister.keegan@gmail.com>
synopsis: Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.
    .
    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.
    .
    New in version 0.1.1: relaxed @containers@ dependency, so it should build on
    GHC 6.10.
category: Algorithms, Text
author: Keegan McAllister <mcallister.keegan@gmail.com>
exposed: True
exposed-modules:
    Data.Algorithm.Patience
abi: a1ce82519e812b01fae540dae910f0d0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/patience-0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/patience-0.1.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/patience-0.1.1
hs-libraries: HSpatience-0.1.1-2guNJXEyIQ0FLSljxNeNTz
depends:
    base-4.9.1.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html: /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
